import { defineConfig } from 'astro/config';
import sitemap from "@astrojs/sitemap";
import vue from "@astrojs/vue";
import remarkToc from 'remark-toc';

// https://astro.build/config
export default defineConfig({
  markdown: {
    smartypants: false,
    syntaxHighlight: 'shiki',
    shikiConfig: {
      // Choose from Shiki's built-in themes (or add your own)
      // https://shiki.style/themes
      theme: 'github-light',
      // Alternatively, provide multiple themes
      // See note below for using dual light/dark themes
      themes: {
        light: 'github-light',
        dark: 'github-dark'
      },
      // Add custom languages
      // Note: Shiki has countless langs built-in, including .astro!
      // https://shiki.style/languages
      langs: [],
      // Enable word wrap to prevent horizontal scrolling
      wrap: false,
      // Add custom transformers: https://shiki.style/guide/transformers
      // Find common transformers: https://shiki.style/packages/transformers
      transformers: []
    },
    remarkPlugins: [
      [remarkToc, { heading: "(table[ -]of[ -])?contents?|toc|目录" }]
    ],
  },
  site: 'https://lishouzhong.com',
  integrations: [
    sitemap({
      customPages: [
        "https://lishouzhong.com/file_share/translation/FreeBSD 13 NFS exports man(5) page 2021 中文译本.html",
        "https://lishouzhong.com/file_share/translation/FreeBSD 13 NFS mountd man(8) page 2020 中文译本.html",
        "https://lishouzhong.com/file_share/translation/FreeBSD 13 NFS nfsd man(8) page 2019 中文译本.html",
        "https://lishouzhong.com/file_share/translation/FreeBSD 13 NFS showmount man(8) page 2016 中文译本.html",
        "https://lishouzhong.com/file_share/translation/FreeBSD 13 NFSv4 man(4) page 2019 中文译本.html",
        "https://lishouzhong.com/file_share/translation/FreeBSD 13 NFSv4 nfscbd man(8) page 2009 中文译本.html",
        "https://lishouzhong.com/file_share/translation/FreeBSD 13 NFSv4 nfsrevoke man(8) page 2009 中文译本.html",
        "https://lishouzhong.com/file_share/translation/FreeBSD 13 NFSv4 nfsuserd man(8) page 2019 中文译本.html",
        "https://lishouzhong.com/file_share/translation/FreeBSD 13 rpcbind man(8) page 2017 中文译本.html",
        "https://lishouzhong.com/file_share/translation/EasyRSA Intro-To-PKI v3.08 中文译本.html",
        "https://lishouzhong.com/file_share/translation/EasyRSA-Advanced v3.08 中文译本.html",
        "https://lishouzhong.com/file_share/translation/EasyRSA-Readme v3.08 中文译本.html",
        "https://lishouzhong.com/file_share/translation/EasyRSA-Upgrade-Notes v3.08 中文译本.html",
        "https://lishouzhong.com/file_share/translation/iperf3 v3.9 man page 中文译本.html",
        "https://lishouzhong.com/file_share/translation/PostgreSQL Don't Do This 中文译本.html",
        "https://lishouzhong.com/file_share/translation/rsync v3.2.7 man(1) page 中文译本.html",
      ],
      // entryLimit: 10000,
      // filter: (page) => { },
      // lastmod: new Date('2022-02-24'),
      // serialize(item) {
      //   return item;
      // }
    }),
    vue()]
});